@@ -7,7 +7,7 @@ RDF::Trine::Graph - Materialized RDF Graphs for testing isomorphism
 
 =head1 VERSION
 
-This document describes RDF::Trine::Graph version 0.125
+This document describes RDF::Trine::Graph version 0.126
 
 =head1 SYNOPSIS
 
@@ -33,9 +33,12 @@ use Math::Combinatorics qw(permute);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '0.125';
+	$VERSION	= '0.126';
 }
 
+use overload	'=='	=> \&RDF::Trine::Graph::equals,
+				'eq'	=> \&RDF::Trine::Graph::equals;
+
 use Data::Dumper;
 use Log::Log4perl;
 use Scalar::Util qw(blessed);
