@@ -7,7 +7,7 @@ RDF::Trine::Parser - RDF Parser class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser version 0.125
+This document describes RDF::Trine::Parser version 0.126
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ our %media_types;
 our %format_uris;
 our %encodings;
 BEGIN {
-	$VERSION	= '0.125';
+	$VERSION	= '0.126';
 }
 
 use Scalar::Util qw(blessed);
@@ -202,7 +202,11 @@ sub parse_into_model {
 			$model->add_statement( $st );
 		}
 	};
-	return $self->parse( $uri, $input, $handler );
+	
+	$model->begin_bulk_ops();
+	my $s	= $self->parse( $uri, $input, $handler );
+	$model->end_bulk_ops();
+	return $s;
 }
 
 =item C<< parse_file_into_model ( $base_uri, $fh, $model [, context => $context] ) >>
@@ -234,7 +238,11 @@ sub parse_file_into_model {
 			$model->add_statement( $st );
 		}
 	};
-	return $self->parse_file( $uri, $fh, $handler );
+	
+	$model->begin_bulk_ops();
+	my $s	= $self->parse_file( $uri, $fh, $handler );
+	$model->end_bulk_ops();
+	return $s;
 }
 
 =item C<< parse_file ( $base, $fh, $handler ) >>
